@@ -45,7 +45,7 @@ def event_monitor(monitor):
     print("event monitor thread done!")
 
 
-ctx = zmq.Context().instance()
+ctx = zmq.Context.instance()
 rep = ctx.socket(zmq.REP)
 req = ctx.socket(zmq.REQ)
 
