@@ -1,23 +1,8 @@
-"""Classes for running 0MQ Devices in the background.
+"""Classes for running 0MQ Devices in the background."""
 
-Authors
--------
-* MinRK
-* Brian Granger
-"""
+# Copyright (C) PyZMQ Developers
+# Distributed under the terms of the Modified BSD License.
 
-#-----------------------------------------------------------------------------
-#  Copyright (c) 2013 Brian Granger, Min Ragan-Kelley
-#
-#  This file is part of pyzmq
-#
-#  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
 
 import time
 from threading import Thread
@@ -25,9 +10,6 @@ from multiprocessing import Process
 
 from zmq import device, QUEUE, Context, ETERM, ZMQError
 
-#-----------------------------------------------------------------------------
-# Classes
-#-----------------------------------------------------------------------------
 
 class Device:
     """A 0MQ Device to be run in the background.
