@@ -1,34 +1,27 @@
-#-----------------------------------------------------------------------------
-#  Copyright (c) 2010-2012 Brian Granger, Min Ragan-Kelley
-#
-#  This file is part of pyzmq
-#
-#  Distributed under the terms of the New BSD License.  The full license is in
-#  the file COPYING.BSD, distributed as part of this software.
-#-----------------------------------------------------------------------------
-
-#-----------------------------------------------------------------------------
-# Imports
-#-----------------------------------------------------------------------------
+# Copyright (C) PyZMQ Developers
+# Distributed under the terms of the Modified BSD License.
 
 import time
 import os
 import threading
 
+import pytest
+
 import zmq
-from zmq.tests import BaseZMQTestCase
+from zmq.tests import BaseZMQTestCase, have_gevent
 from zmq.eventloop import ioloop
-from zmq.eventloop.minitornado.ioloop import _Timeout
+try:
+    from tornado.ioloop import IOLoop as BaseIOLoop
+except ImportError:
+    from zmq.eventloop.minitornado.ioloop import IOLoop as BaseIOLoop
 
 
-#-----------------------------------------------------------------------------
-# Tests
-#-----------------------------------------------------------------------------
 def printer():
     os.system("say hello")
     raise Exception
     print (time.time())
 
+
 class Delay(threading.Thread):
     def __init__(self, f, delay=1):
         self.f=f
@@ -50,8 +43,14 @@ class Delay(threading.Thread):
         self.cond.notify()
         self.cond.release()
 
+
 class TestIOLoop(BaseZMQTestCase):
 
+    def tearDown(self):
+        super(TestIOLoop, self).tearDown()
+        BaseIOLoop.clear_current()
+        BaseIOLoop.clear_instance()
+
     def test_simple(self):
         """simple IOLoop creation test"""
         loop = ioloop.IOLoop()
@@ -67,15 +66,6 @@ class TestIOLoop(BaseZMQTestCase):
         else:
             self.fail("IOLoop failed to exit")
     
-    def test_timeout_compare(self):
-        """test timeout comparisons"""
-        loop = ioloop.IOLoop()
-        t = _Timeout(1, 2, loop)
-        t2 = _Timeout(1, 3, loop)
-        self.assertEqual(t < t2, id(t) < id(t2))
-        t2 = _Timeout(2,1, loop)
-        self.assertTrue(t < t2)
-
     def test_poller_events(self):
         """Tornado poller implementation maps events correctly"""
         req,rep = self.create_bound_pair(zmq.REQ, zmq.REP)
@@ -97,12 +87,21 @@ class TestIOLoop(BaseZMQTestCase):
         events = dict(poller.poll(1))
         self.assertEqual(events.get(rep), ioloop.IOLoop.READ)
         self.assertEqual(events.get(req), None)
-    
+
     def test_instance(self):
-        """Test IOLoop.instance returns the right object"""
+        """Green IOLoop.instance returns the right object"""
         loop = ioloop.IOLoop.instance()
-        self.assertEqual(loop.__class__, ioloop.IOLoop)
-    
+        assert isinstance(loop, ioloop.IOLoop)
+        base_loop = BaseIOLoop.instance()
+        assert base_loop is loop
+
+    def test_current(self):
+        """Green IOLoop.current returns the right object"""
+        loop = ioloop.IOLoop.current()
+        assert isinstance(loop, ioloop.IOLoop)
+        base_loop = BaseIOLoop.current()
+        assert base_loop is loop
+
     def test_close_all(self):
         """Test close(all_fds=True)"""
         loop = ioloop.IOLoop.instance()
@@ -116,3 +115,21 @@ class TestIOLoop(BaseZMQTestCase):
         self.assertEqual(rep.closed, True)
         
 
+if have_gevent:
+    import zmq.green.eventloop.ioloop as green_ioloop
+    
+    class TestIOLoopGreen(BaseZMQTestCase):
+        def test_instance(self):
+            """Green IOLoop.instance returns the right object"""
+            loop = green_ioloop.IOLoop.instance()
+            assert isinstance(loop, green_ioloop.IOLoop)
+            base_loop = BaseIOLoop.instance()
+            assert base_loop is loop
+    
+        def test_current(self):
+            """Green IOLoop.current returns the right object"""
+            loop = green_ioloop.IOLoop.current()
+            assert isinstance(loop, green_ioloop.IOLoop)
+            base_loop = BaseIOLoop.current()
+            assert base_loop is loop
+    
